#ifndef AT91SAM7_h
#define AT91SAM7_h
#define AIC_SMR0 (*(volatile unsigned long *)0xfffff000)
#define AIC_SMR1 (*(volatile unsigned long *)0xfffff004)
#define AIC_SMR2 (*(volatile unsigned long *)0xfffff008)
#define AIC_SMR3 (*(volatile unsigned long *)0xfffff00c)
#define AIC_SMR4 (*(volatile unsigned long *)0xfffff010)
#define AIC_SMR5 (*(volatile unsigned long *)0xfffff014)
#define AIC_SMR6 (*(volatile unsigned long *)0xfffff018)
#define AIC_SMR7 (*(volatile unsigned long *)0xfffff01c)
#define AIC_SMR8 (*(volatile unsigned long *)0xfffff020)
#define AIC_SMR9 (*(volatile unsigned long *)0xfffff024)
#define AIC_SMR10 (*(volatile unsigned long *)0xfffff028)
#define AIC_SMR11 (*(volatile unsigned long *)0xfffff02c)
#define AIC_SMR12 (*(volatile unsigned long *)0xfffff030)
#define AIC_SMR13 (*(volatile unsigned long *)0xfffff034)
#define AIC_SMR14 (*(volatile unsigned long *)0xfffff038)
#define AIC_SMR15 (*(volatile unsigned long *)0xfffff03c)
#define AIC_SMR16 (*(volatile unsigned long *)0xfffff040)
#define AIC_SMR17 (*(volatile unsigned long *)0xfffff044)
#define AIC_SMR18 (*(volatile unsigned long *)0xfffff048)
#define AIC_SMR19 (*(volatile unsigned long *)0xfffff04c)
#define AIC_SMR20 (*(volatile unsigned long *)0xfffff050)
#define AIC_SMR21 (*(volatile unsigned long *)0xfffff054)
#define AIC_SMR22 (*(volatile unsigned long *)0xfffff058)
#define AIC_SMR23 (*(volatile unsigned long *)0xfffff05c)
#define AIC_SMR24 (*(volatile unsigned long *)0xfffff060)
#define AIC_SMR25 (*(volatile unsigned long *)0xfffff064)
#define AIC_SMR26 (*(volatile unsigned long *)0xfffff068)
#define AIC_SMR27 (*(volatile unsigned long *)0xfffff06c)
#define AIC_SMR28 (*(volatile unsigned long *)0xfffff070)
#define AIC_SMR29 (*(volatile unsigned long *)0xfffff074)
#define AIC_SMR30 (*(volatile unsigned long *)0xfffff078)
#define AIC_SMR31 (*(volatile unsigned long *)0xfffff07c)
#define AIC_SVR0 (*(volatile unsigned long *)0xfffff080)
#define AIC_SVR1 (*(volatile unsigned long *)0xfffff084)
#define AIC_SVR2 (*(volatile unsigned long *)0xfffff088)
#define AIC_SVR3 (*(volatile unsigned long *)0xfffff08c)
#define AIC_SVR4 (*(volatile unsigned long *)0xfffff090)
#define AIC_SVR5 (*(volatile unsigned long *)0xfffff094)
#define AIC_SVR6 (*(volatile unsigned long *)0xfffff098)
#define AIC_SVR7 (*(volatile unsigned long *)0xfffff09c)
#define AIC_SVR8 (*(volatile unsigned long *)0xfffff0a0)
#define AIC_SVR9 (*(volatile unsigned long *)0xfffff0a4)
#define AIC_SVR10 (*(volatile unsigned long *)0xfffff0a8)
#define AIC_SVR11 (*(volatile unsigned long *)0xfffff0ac)
#define AIC_SVR12 (*(volatile unsigned long *)0xfffff0b0)
#define AIC_SVR13 (*(volatile unsigned long *)0xfffff0b4)
#define AIC_SVR14 (*(volatile unsigned long *)0xfffff0b8)
#define AIC_SVR15 (*(volatile unsigned long *)0xfffff0bc)
#define AIC_SVR16 (*(volatile unsigned long *)0xfffff0c0)
#define AIC_SVR17 (*(volatile unsigned long *)0xfffff0c4)
#define AIC_SVR18 (*(volatile unsigned long *)0xfffff0c8)
#define AIC_SVR19 (*(volatile unsigned long *)0xfffff0cc)
#define AIC_SVR20 (*(volatile unsigned long *)0xfffff0d0)
#define AIC_SVR21 (*(volatile unsigned long *)0xfffff0d4)
#define AIC_SVR22 (*(volatile unsigned long *)0xfffff0d8)
#define AIC_SVR23 (*(volatile unsigned long *)0xfffff0dc)
#define AIC_SVR24 (*(volatile unsigned long *)0xfffff0e0)
#define AIC_SVR25 (*(volatile unsigned long *)0xfffff0e4)
#define AIC_SVR26 (*(volatile unsigned long *)0xfffff0e8)
#define AIC_SVR27 (*(volatile unsigned long *)0xfffff0ec)
#define AIC_SVR28 (*(volatile unsigned long *)0xfffff0f0)
#define AIC_SVR29 (*(volatile unsigned long *)0xfffff0f4)
#define AIC_SVR30 (*(volatile unsigned long *)0xfffff0f8)
#define AIC_SVR31 (*(volatile unsigned long *)0xfffff0fc)
#define AIC_IVR (*(volatile unsigned long *)0xfffff100)
#define AIC_FVR (*(volatile unsigned long *)0xfffff104)
#define AIC_ISR (*(volatile unsigned long *)0xfffff108)
#define AIC_IPR (*(volatile unsigned long *)0xfffff10c)
#define AIC_IMR (*(volatile unsigned long *)0xfffff110)
#define AIC_CISR (*(volatile unsigned long *)0xfffff114)
#define AIC_IECR (*(volatile unsigned long *)0xfffff120)
#define AIC_IDCR (*(volatile unsigned long *)0xfffff124)
#define AIC_ICCR (*(volatile unsigned long *)0xfffff128)
#define AIC_ISCR (*(volatile unsigned long *)0xfffff12c)
#define AIC_EOICR (*(volatile unsigned long *)0xfffff130)
#define AIC_SPU (*(volatile unsigned long *)0xfffff134)
#define AIC_DEBUG (*(volatile unsigned long *)0xfffff138)
#define AIC_FFER (*(volatile unsigned long *)0xfffff140)
#define AIC_FFDR (*(volatile unsigned long *)0xfffff144)
#define AIC_FFSR (*(volatile unsigned long *)0xfffff148)
#define DBGU_CR (*(volatile unsigned long *)0xfffff200)
#define DBGU_MR (*(volatile unsigned long *)0xfffff204)
#define DBGU_IER (*(volatile unsigned long *)0xfffff208)
#define DBGU_IDR (*(volatile unsigned long *)0xfffff20c)
#define DBGU_IMR (*(volatile unsigned long *)0xfffff210)
#define DBGU_SR (*(volatile unsigned long *)0xfffff214)
#define DBGU_RHR (*(volatile unsigned long *)0xfffff218)
#define DBGU_THR (*(volatile unsigned long *)0xfffff21c)
#define DBGU_BRGR (*(volatile unsigned long *)0xfffff220)
#define DBGU_CIDR (*(volatile unsigned long *)0xfffff240)
#define DBGU_EXID (*(volatile unsigned long *)0xfffff244)
#define DBGU_FNR (*(volatile unsigned long *)0xfffff248)
#define DBGU_RPR (*(volatile unsigned long *)0xfffff300)
#define DBGU_RCR (*(volatile unsigned long *)0xfffff304)
#define DBGU_TPR (*(volatile unsigned long *)0xfffff308)
#define DBGU_TCR (*(volatile unsigned long *)0xfffff30c)
#define DBGU_RNPR (*(volatile unsigned long *)0xfffff310)
#define DBGU_RNCR (*(volatile unsigned long *)0xfffff314)
#define DBGU_TNPR (*(volatile unsigned long *)0xfffff318)
#define DBGU_TNCR (*(volatile unsigned long *)0xfffff31c)
#define DBGU_PTCR (*(volatile unsigned long *)0xfffff320)
#define DBGU_PTSR (*(volatile unsigned long *)0xfffff324)
#define PIOA_PER (*(volatile unsigned long *)0xfffff400)
#define PIOA_PDR (*(volatile unsigned long *)0xfffff404)
#define PIOA_PSR (*(volatile unsigned long *)0xfffff408)
#define PIOA_OER (*(volatile unsigned long *)0xfffff410)
#define PIOA_ODR (*(volatile unsigned long *)0xfffff414)
#define PIOA_OSR (*(volatile unsigned long *)0xfffff418)
#define PIOA_IFER (*(volatile unsigned long *)0xfffff420)
#define PIOA_IFDR (*(volatile unsigned long *)0xfffff424)
#define PIOA_IFSR (*(volatile unsigned long *)0xfffff428)
#define PIOA_SODR (*(volatile unsigned long *)0xfffff430)
#define PIOA_CODR (*(volatile unsigned long *)0xfffff434)
#define PIOA_ODSR (*(volatile unsigned long *)0xfffff438)
#define PIOA_PDSR (*(volatile unsigned long *)0xfffff43c)
#define PIOA_IER (*(volatile unsigned long *)0xfffff440)
#define PIOA_IDR (*(volatile unsigned long *)0xfffff444)
#define PIOA_IMR (*(volatile unsigned long *)0xfffff448)
#define PIOA_ISR (*(volatile unsigned long *)0xfffff44c)
#define PIOA_MDER (*(volatile unsigned long *)0xfffff450)
#define PIOA_MDDR (*(volatile unsigned long *)0xfffff454)
#define PIOA_MDSR (*(volatile unsigned long *)0xfffff458)
#define PIOA_PUDR (*(volatile unsigned long *)0xfffff460)
#define PIOA_PUER (*(volatile unsigned long *)0xfffff464)
#define PIOA_PUSR (*(volatile unsigned long *)0xfffff468)
#define PIOA_ASR (*(volatile unsigned long *)0xfffff470)
#define PIOA_BSR (*(volatile unsigned long *)0xfffff474)
#define PIOA_ABSR (*(volatile unsigned long *)0xfffff478)
#define PIOA_OWER (*(volatile unsigned long *)0xfffff4a0)
#define PIOA_OWDR (*(volatile unsigned long *)0xfffff4a4)
#define PIOA_OWSR (*(volatile unsigned long *)0xfffff4a8)
#define PMC_SCER (*(volatile unsigned long *)0xfffffc00)
#define PMC_SCDR (*(volatile unsigned long *)0xfffffc04)
#define PMC_SCSR (*(volatile unsigned long *)0xfffffc08)
#define PMC_PCER (*(volatile unsigned long *)0xfffffc10)
#define PMC_PCDR (*(volatile unsigned long *)0xfffffc14)
#define PMC_PCSR (*(volatile unsigned long *)0xfffffc18)
#define CKGR_MOR (*(volatile unsigned long *)0xfffffc20)
#define CKGR_MCFR (*(volatile unsigned long *)0xfffffc24)
#define CKGR_PLLR (*(volatile unsigned long *)0xfffffc2c)
#define PMC_MCKR (*(volatile unsigned long *)0xfffffc30)
#define PMC_PCK0 (*(volatile unsigned long *)0xfffffc40)
#define PMC_PCK1 (*(volatile unsigned long *)0xfffffc44)
#define PMC_IER (*(volatile unsigned long *)0xfffffc60)
#define PMC_IDR (*(volatile unsigned long *)0xfffffc64)
#define PMC_SR (*(volatile unsigned long *)0xfffffc68)
#define PMC_IMR (*(volatile unsigned long *)0xfffffc6c)
#define RSTC_CR (*(volatile unsigned long *)0xfffffd00)
#define RSTC_SR (*(volatile unsigned long *)0xfffffd04)
#define RSTC_MR (*(volatile unsigned long *)0xfffffd08)
#define RTT_MR (*(volatile unsigned long *)0xfffffd20)
#define RTT_AR (*(volatile unsigned long *)0xfffffd24)
#define RTT_VR (*(volatile unsigned long *)0xfffffd28)
#define RTT_SR (*(volatile unsigned long *)0xfffffd2c)
#define PIT_MR (*(volatile unsigned long *)0xfffffd30)
#define PIT_SR (*(volatile unsigned long *)0xfffffd34)
#define PIT_PIVR (*(volatile unsigned long *)0xfffffd38)
#define PIT_PIIR (*(volatile unsigned long *)0xfffffd3c)
#define WDT_CR (*(volatile unsigned long *)0xfffffd40)
#define WDT_MR (*(volatile unsigned long *)0xfffffd44)
#define WDT_SR (*(volatile unsigned long *)0xfffffd48)
#define WREG_MR (*(volatile unsigned long *)0xfffffd60)
#define MC_RCR (*(volatile unsigned long *)0xffffff00)
#define MC_ASR (*(volatile unsigned long *)0xffffff04)
#define MC_AASR (*(volatile unsigned long *)0xffffff08)
#define MC_FMR (*(volatile unsigned long *)0xffffff60)
#define MC_FCR (*(volatile unsigned long *)0xffffff64)
#define MC_FSR (*(volatile unsigned long *)0xffffff68)
#define TC0_CCR (*(volatile unsigned long *)0xfffa0000)
#define TC0_CMR (*(volatile unsigned long *)0xfffa0004)
#define TC0_CV (*(volatile unsigned long *)0xfffa0010)
#define TC0_RA (*(volatile unsigned long *)0xfffa0014)
#define TC0_RB (*(volatile unsigned long *)0xfffa0018)
#define TC0_RC (*(volatile unsigned long *)0xfffa001c)
#define TC0_SR (*(volatile unsigned long *)0xfffa0020)
#define TC0_IER (*(volatile unsigned long *)0xfffa0024)
#define TC0_IDR (*(volatile unsigned long *)0xfffa0028)
#define TC0_IMR (*(volatile unsigned long *)0xfffa002c)
#define TC1_CCR (*(volatile unsigned long *)0xfffa0040)
#define TC1_CMR (*(volatile unsigned long *)0xfffa0044)
#define TC1_CV (*(volatile unsigned long *)0xfffa0050)
#define TC1_RA (*(volatile unsigned long *)0xfffa0054)
#define TC1_RB (*(volatile unsigned long *)0xfffa0058)
#define TC1_RC (*(volatile unsigned long *)0xfffa005c)
#define TC1_SR (*(volatile unsigned long *)0xfffa0060)
#define TC1_IER (*(volatile unsigned long *)0xfffa0064)
#define TC1_IDR (*(volatile unsigned long *)0xfffa0068)
#define TC1_IMR (*(volatile unsigned long *)0xfffa006c)
#define TC2_CCR (*(volatile unsigned long *)0xfffa0080)
#define TC2_CMR (*(volatile unsigned long *)0xfffa0084)
#define TC2_CV (*(volatile unsigned long *)0xfffa0090)
#define TC2_RA (*(volatile unsigned long *)0xfffa0094)
#define TC2_RB (*(volatile unsigned long *)0xfffa0098)
#define TC2_RC (*(volatile unsigned long *)0xfffa009c)
#define TC2_SR (*(volatile unsigned long *)0xfffa00a0)
#define TC2_IER (*(volatile unsigned long *)0xfffa00a4)
#define TC2_IDR (*(volatile unsigned long *)0xfffa00a8)
#define TC2_IMR (*(volatile unsigned long *)0xfffa00ac)
#define TC_BCR (*(volatile unsigned long *)0xfffa00c0)
#define TC_BMR (*(volatile unsigned long *)0xfffa00c4)
#define USB_FRM_NUM (*(volatile unsigned long *)0xfffb0000)
#define USB_GLB_STAT (*(volatile unsigned long *)0xfffb0004)
#define USB_FADDR (*(volatile unsigned long *)0xfffb0008)
#define USB_IER (*(volatile unsigned long *)0xfffb0010)
#define USB_IDR (*(volatile unsigned long *)0xfffb0014)
#define USB_IMR (*(volatile unsigned long *)0xfffb0018)
#define USB_ISR (*(volatile unsigned long *)0xfffb001c)
#define USB_ICR (*(volatile unsigned long *)0xfffb0020)
#define USB_RST_EP (*(volatile unsigned long *)0xfffb0028)
#define USB_CSR0 (*(volatile unsigned long *)0xfffb0030)
#define USB_CSR1 (*(volatile unsigned long *)0xfffb0034)
#define USB_CSR2 (*(volatile unsigned long *)0xfffb0038)
#define USB_CSR3 (*(volatile unsigned long *)0xfffb003c)
#define USB_FDR0 (*(volatile unsigned long *)0xfffb0050)
#define USB_FDR1 (*(volatile unsigned long *)0xfffb0054)
#define USB_FDR2 (*(volatile unsigned long *)0xfffb0058)
#define USB_FDR3 (*(volatile unsigned long *)0xfffb005c)
#define USB_TXVC (*(volatile unsigned long *)0xfffb0074)
#define TWI_CR (*(volatile unsigned long *)0xfffb8000)
#define TWI_MMR (*(volatile unsigned long *)0xfffb8004)
#define TWI_IADR (*(volatile unsigned long *)0xfffb800c)
#define TWI_CWGR (*(volatile unsigned long *)0xfffb8010)
#define TWI_SR (*(volatile unsigned long *)0xfffb8020)
#define TWI_IER (*(volatile unsigned long *)0xfffb8024)
#define TWI_IDR (*(volatile unsigned long *)0xfffb8028)
#define TWI_IMR (*(volatile unsigned long *)0xfffb802c)
#define TWI_RHR (*(volatile unsigned long *)0xfffb8030)
#define TWI_THR (*(volatile unsigned long *)0xfffb8034)
#define US0_CR (*(volatile unsigned long *)0xfffc0000)
#define US0_MR (*(volatile unsigned long *)0xfffc0004)
#define US0_IER (*(volatile unsigned long *)0xfffc0008)
#define US0_IDR (*(volatile unsigned long *)0xfffc000c)
#define US0_IMR (*(volatile unsigned long *)0xfffc0010)
#define US0_CSR (*(volatile unsigned long *)0xfffc0014)
#define US0_RHR (*(volatile unsigned long *)0xfffc0018)
#define US0_THR (*(volatile unsigned long *)0xfffc001c)
#define US0_BRGR (*(volatile unsigned long *)0xfffc0020)
#define US0_RTOR (*(volatile unsigned long *)0xfffc0024)
#define US0_TTGR (*(volatile unsigned long *)0xfffc0028)
#define US0_FIDI (*(volatile unsigned long *)0xfffc0040)
#define US0_NER (*(volatile unsigned long *)0xfffc0044)
#define US0_IF (*(volatile unsigned long *)0xfffc004c)
#define US0_RPR (*(volatile unsigned long *)0xfffc0100)
#define US0_RCR (*(volatile unsigned long *)0xfffc0104)
#define US0_TPR (*(volatile unsigned long *)0xfffc0108)
#define US0_TCR (*(volatile unsigned long *)0xfffc010c)
#define US0_RNPR (*(volatile unsigned long *)0xfffc0110)
#define US0_RNCR (*(volatile unsigned long *)0xfffc0114)
#define US0_TNPR (*(volatile unsigned long *)0xfffc0118)
#define US0_TNCR (*(volatile unsigned long *)0xfffc011c)
#define US0_PTCR (*(volatile unsigned long *)0xfffc0120)
#define US0_PTSR (*(volatile unsigned long *)0xfffc0124)
#define US1_CR (*(volatile unsigned long *)0xfffc4000)
#define US1_MR (*(volatile unsigned long *)0xfffc4004)
#define US1_IER (*(volatile unsigned long *)0xfffc4008)
#define US1_IDR (*(volatile unsigned long *)0xfffc400c)
#define US1_IMR (*(volatile unsigned long *)0xfffc4010)
#define US1_CSR (*(volatile unsigned long *)0xfffc4014)
#define US1_RHR (*(volatile unsigned long *)0xfffc4018)
#define US1_THR (*(volatile unsigned long *)0xfffc401c)
#define US1_BRGR (*(volatile unsigned long *)0xfffc4020)
#define US1_RTOR (*(volatile unsigned long *)0xfffc4024)
#define US1_TTGR (*(volatile unsigned long *)0xfffc4028)
#define US1_FIDI (*(volatile unsigned long *)0xfffc4040)
#define US1_NER (*(volatile unsigned long *)0xfffc4044)
#define US1_IF (*(volatile unsigned long *)0xfffc404c)
#define US1_RPR (*(volatile unsigned long *)0xfffc4100)
#define US1_RCR (*(volatile unsigned long *)0xfffc4104)
#define US1_TPR (*(volatile unsigned long *)0xfffc4108)
#define US1_TCR (*(volatile unsigned long *)0xfffc410c)
#define US1_RNPR (*(volatile unsigned long *)0xfffc4110)
#define US1_RNCR (*(volatile unsigned long *)0xfffc4114)
#define US1_TNPR (*(volatile unsigned long *)0xfffc4118)
#define US1_TNCR (*(volatile unsigned long *)0xfffc411c)
#define US1_PTCR (*(volatile unsigned long *)0xfffc4120)
#define US1_PTSR (*(volatile unsigned long *)0xfffc4124)
#define PWM_MR (*(volatile unsigned long *)0xfffcc000)
#define PWM_ENA (*(volatile unsigned long *)0xfffcc004)
#define PWM_DIS (*(volatile unsigned long *)0xfffcc008)
#define PWM_SR (*(volatile unsigned long *)0xfffcc00c)
#define PWM_IER (*(volatile unsigned long *)0xfffcc010)
#define PWM_IDR (*(volatile unsigned long *)0xfffcc014)
#define PWM_IMR (*(volatile unsigned long *)0xfffcc018)
#define PWM_ISR (*(volatile unsigned long *)0xfffcc01c)
#define PWM_VERSION (*(volatile unsigned long *)0xfffcc0fc)
#define PWM_CMR0 (*(volatile unsigned long *)0xfffcc200)
#define PWM_CDTY0 (*(volatile unsigned long *)0xfffcc204)
#define PWM_CPRD0 (*(volatile unsigned long *)0xfffcc208)
#define PWM_CCNT0 (*(volatile unsigned long *)0xfffcc20c)
#define PWM_CUPD0 (*(volatile unsigned long *)0xfffcc210)
#define PWM_CMR1 (*(volatile unsigned long *)0xfffcc220)
#define PWM_CDTY1 (*(volatile unsigned long *)0xfffcc224)
#define PWM_CPRD1 (*(volatile unsigned long *)0xfffcc228)
#define PWM_CCNT1 (*(volatile unsigned long *)0xfffcc22c)
#define PWM_CUPD1 (*(volatile unsigned long *)0xfffcc230)
#define SSC_CR (*(volatile unsigned long *)0xfffd4000)
#define SSC_CMR (*(volatile unsigned long *)0xfffd4004)
#define SSC_RCMR (*(volatile unsigned long *)0xfffd4010)
#define SSC_RFMR (*(volatile unsigned long *)0xfffd4014)
#define SSC_TCMR (*(volatile unsigned long *)0xfffd4018)
#define SSC_TFMR (*(volatile unsigned long *)0xfffd401c)
#define SSC_RHR (*(volatile unsigned long *)0xfffd4020)
#define SSC_THR (*(volatile unsigned long *)0xfffd4024)
#define SSC_RSHR (*(volatile unsigned long *)0xfffd4030)
#define SSC_TSHR (*(volatile unsigned long *)0xfffd4034)
#define SSC_SR (*(volatile unsigned long *)0xfffd4040)
#define SSC_IER (*(volatile unsigned long *)0xfffd4044)
#define SSC_IDR (*(volatile unsigned long *)0xfffd4048)
#define SSC_IMR (*(volatile unsigned long *)0xfffd404c)
#define SSC_RPR (*(volatile unsigned long *)0xfffd4100)
#define SSC_RCR (*(volatile unsigned long *)0xfffd4104)
#define SSC_TPR (*(volatile unsigned long *)0xfffd4108)
#define SSC_TCR (*(volatile unsigned long *)0xfffd410c)
#define SSC_RNPR (*(volatile unsigned long *)0xfffd4110)
#define SSC_RNCR (*(volatile unsigned long *)0xfffd4114)
#define SSC_TNPR (*(volatile unsigned long *)0xfffd4118)
#define SSC_TNCR (*(volatile unsigned long *)0xfffd411c)
#define SSC_PTCR (*(volatile unsigned long *)0xfffd4120)
#define SSC_PTSR (*(volatile unsigned long *)0xfffd4124)
#define ADC_CR (*(volatile unsigned long *)0xfffd8000)
#define ADC_MR (*(volatile unsigned long *)0xfffd8004)
#define ADC_CHER (*(volatile unsigned long *)0xfffd8010)
#define ADC_CHDR (*(volatile unsigned long *)0xfffd8014)
#define ADC_CHSR (*(volatile unsigned long *)0xfffd8018)
#define ADC_SR (*(volatile unsigned long *)0xfffd801c)
#define ADC_LCDR (*(volatile unsigned long *)0xfffd8020)
#define ADC_IER (*(volatile unsigned long *)0xfffd8024)
#define ADC_IDR (*(volatile unsigned long *)0xfffd8028)
#define ADC_IMR (*(volatile unsigned long *)0xfffd802c)
#define ADC_CDR0 (*(volatile unsigned long *)0xfffd8030)
#define ADC_CDR1 (*(volatile unsigned long *)0xfffd8034)
#define ADC_CDR2 (*(volatile unsigned long *)0xfffd8038)
#define ADC_CDR3 (*(volatile unsigned long *)0xfffd803c)
#define ADC_CDR4 (*(volatile unsigned long *)0xfffd8040)
#define ADC_CDR5 (*(volatile unsigned long *)0xfffd8044)
#define ADC_CDR6 (*(volatile unsigned long *)0xfffd8048)
#define ADC_CDR7 (*(volatile unsigned long *)0xfffd804c)
#define ADC_RPR (*(volatile unsigned long *)0xfffd8100)
#define ADC_RCR (*(volatile unsigned long *)0xfffd8104)
#define ADC_TPR (*(volatile unsigned long *)0xfffd8108)
#define ADC_TCR (*(volatile unsigned long *)0xfffd810c)
#define ADC_RNPR (*(volatile unsigned long *)0xfffd8110)
#define ADC_RNCR (*(volatile unsigned long *)0xfffd8114)
#define ADC_TNPR (*(volatile unsigned long *)0xfffd8118)
#define ADC_TNCR (*(volatile unsigned long *)0xfffd811c)
#define ADC_PTCR (*(volatile unsigned long *)0xfffd8120)
#define ADC_PTSR (*(volatile unsigned long *)0xfffd8124)
#define SPI_CR (*(volatile unsigned long *)0xfffe0000)
#define SPI_MR (*(volatile unsigned long *)0xfffe0004)
#define SPI_RDR (*(volatile unsigned long *)0xfffe0008)
#define SPI_TDR (*(volatile unsigned long *)0xfffe000c)
#define SPI_SR (*(volatile unsigned long *)0xfffe0010)
#define SPI_IER (*(volatile unsigned long *)0xfffe0014)
#define SPI_IDR (*(volatile unsigned long *)0xfffe0018)
#define SPI_IMR (*(volatile unsigned long *)0xfffe001c)
#define SPI_CSR0 (*(volatile unsigned long *)0xfffe0030)
#define SPI_CSR1 (*(volatile unsigned long *)0xfffe0034)
#define SPI_CSR2 (*(volatile unsigned long *)0xfffe0038)
#define SPI_CSR3 (*(volatile unsigned long *)0xfffe003c)
#define SPI_RPR (*(volatile unsigned long *)0xfffe0100)
#define SPI_RCR (*(volatile unsigned long *)0xfffe0104)
#define SPI_TPR (*(volatile unsigned long *)0xfffe0108)
#define SPI_TCR (*(volatile unsigned long *)0xfffe010c)
#define SPI_RNPR (*(volatile unsigned long *)0xfffe0110)
#define SPI_RNCR (*(volatile unsigned long *)0xfffe0114)
#define SPI_TNPR (*(volatile unsigned long *)0xfffe0118)
#define SPI_TNCR (*(volatile unsigned long *)0xfffe011c)
#define SPI_PTCR (*(volatile unsigned long *)0xfffe0120)
#define SPI_PTSR (*(volatile unsigned long *)0xfffe0124)
#endif
